==> qmmp_2.2.8.orig.tar.bz2: qmmp-2.2.8/src/plugins/Input/xmp/translations/xmp_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="39"/>
        <source>XMP Plugin</source>
        <translation>Втулок XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="54"/>
        <source>Module Files</source>
        <translation>Трекерна музика</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="109"/>
        <source>About XMP Audio Plugin</source>
        <translation>Про авдіовтулок XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="110"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Авдіовтулок XMP для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="111"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов  &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>Compiled against libxmp-%1</source>
        <translation>Зібрано з libxmp-%1</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="51"/>
        <source>Volume scale</source>
        <translation>Підсилення</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="52"/>
        <source>Number of patterns</source>
        <translation>Кількість паттернів</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="53"/>
        <source>Number of tracks</source>
        <translation>Кількість доріжок</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Tracks per pattern</source>
        <translation>Доріжок на паттерн</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Number of instruments</source>
        <translation>Кількість знадобів</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of samples</source>
        <translation>Кількість семплів</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Initial speed</source>
        <translation>Початкова швидкість</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Initial BPM</source>
        <translation>Початкова кількість нот на хвилину</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Module length in patterns</source>
        <translation>Довжина в паттернах</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="79"/>
        <source>Samples</source>
        <translation>Семпли</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="87"/>
        <source>Instruments</source>
        <translation>Знадоби</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="92"/>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
</context>
<context>
    <name>XmpSettingsDialog</name>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>Налаштування втулка XMP</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="34"/>
        <source>Amplification factor:</source>
        <translation>Підсилення:</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>Змішування каналів:</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>Тип інтерполяції:</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>Низькочастотний фільтр</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>Використовувати кадровий імпульс гасіння</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>Імітувати помилку Protracker 2.x FX9</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>Частота дискретизації:</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="109"/>
        <source>Emulate sample loop bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="116"/>
        <source>Use Paula mixer in Amiga modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Гц</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 Гц</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 Гц</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation>Методом ближчогого сусіда</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>Лінійна</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation>Кубічними сплайнами</translation>
    </message>
</context>
</TS>

==> qmmp_2.3.0.orig.tar.bz2: qmmp-2.3.0/src/plugins/Input/xmp/translations/xmp_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="39"/>
        <source>XMP Plugin</source>
        <translation>Втулок XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="54"/>
        <source>Module Files</source>
        <translation>Трекерна музика</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="109"/>
        <source>About XMP Audio Plugin</source>
        <translation>Про авдіовтулок XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="110"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Авдіовтулок XMP для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="111"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов  &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>Compiled against libxmp-%1</source>
        <translation>Зібрано з libxmp-%1</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="51"/>
        <source>Volume scale</source>
        <translation>Підсилення</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="52"/>
        <source>Number of patterns</source>
        <translation>Кількість паттернів</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="53"/>
        <source>Number of tracks</source>
        <translation>Кількість доріжок</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Tracks per pattern</source>
        <translation>Доріжок на паттерн</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Number of instruments</source>
        <translation>Кількість знадобів</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of samples</source>
        <translation>Кількість семплів</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Initial speed</source>
        <translation>Початкова швидкість</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Initial BPM</source>
        <translation>Початкова кількість нот на хвилину</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Module length in patterns</source>
        <translation>Довжина в паттернах</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="79"/>
        <source>Samples</source>
        <translation>Семпли</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="87"/>
        <source>Instruments</source>
        <translation>Знадоби</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="92"/>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
</context>
<context>
    <name>XmpSettingsDialog</name>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>Налаштування втулка XMP</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="34"/>
        <source>Amplification factor:</source>
        <translation>Підсилення:</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>Змішування каналів:</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>Тип інтерполяції:</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>Низькочастотний фільтр</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>Використовувати кадровий імпульс гасіння</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>Імітувати помилку Protracker 2.x FX9</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>Частота дискретизації:</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="109"/>
        <source>Emulate sample loop bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.ui" line="116"/>
        <source>Use Paula mixer in Amiga modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Гц</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 Гц</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 Гц</translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="36"/>
        <source>Nearest Neighbor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="38"/>
        <source>Cubic Spline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpsettingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>Лінійна</translation>
    </message>
</context>
</TS>
